"""Models for bluetooth."""
from __future__ import annotations

from collections.abc import Callable
from dataclasses import dataclass
from enum import Enum
from typing import Final

from bleak import BaseBleakClient
from bluetooth_data_tools import monotonic_time_coarse

MONOTONIC_TIME: Final = monotonic_time_coarse


@dataclass(slots=True)
class HaBluetoothConnector:
    """Data for how to connect a BLEDevice from a given scanner."""

    client: type[BaseBleakClient]
    source: str
    can_connect: Callable[[], bool]


class BluetoothScanningMode(Enum):
    """The mode of scanning for bluetooth devices."""

    PASSIVE = "passive"
    ACTIVE = "active"



__version__ = "0.5.1"

from .base_scanner import BaseHaRemoteScanner, BaseHaScanner
from .const import (
    CONNECTABLE_FALLBACK_MAXIMUM_STALE_ADVERTISEMENT_SECONDS,
    FALLBACK_MAXIMUM_STALE_ADVERTISEMENT_SECONDS,
    SCANNER_WATCHDOG_INTERVAL,
    SCANNER_WATCHDOG_TIMEOUT,
)
from .models import HaBluetoothConnector
from .scanner import BluetoothScanningMode, HaScanner, ScannerStartError

__all__ = [
    "BluetoothScanningMode",
    "ScannerStartError",
    "HaScanner",
    "BaseHaScanner",
    "BaseHaRemoteScanner",
    "HaBluetoothConnector",
    "FALLBACK_MAXIMUM_STALE_ADVERTISEMENT_SECONDS",
    "CONNECTABLE_FALLBACK_MAXIMUM_STALE_ADVERTISEMENT_SECONDS",
    "SCANNER_WATCHDOG_TIMEOUT",
    "SCANNER_WATCHDOG_INTERVAL",
]
